%%%% Sensor placement analysis of the model in 
%%%% "Structural analysis for the sensor location problem
%%%% in fault detection and isolation" by C. Commault, 
%%%% J. Dion and S.Y. Agha, Proceedings of Safeprocess'06 
%%%% Beijing, China.
%%%%
%%%% To compare results, remember the difference that in this
%%%% approach, in contrast to the Commault et.al. paper, 
%%%% the fault signals are not considered measurable.

%% Define model structure and define structural model object.
X = [0 0 0 0 1 0 0;... %f1
     0 0 0 0 0 0 1;... %f2
     0 0 0 0 0 1 0;... %f4
     1 0 0 0 1 0 1;...
     0 1 0 0 0 1 0;... %f3
     1 1 1 0 0 0 0;...     
     1 1 0 1 0 0 0;...
     0 0 1 0 0 0 0;... %y1
     0 0 1 1 0 0 0;... %y2
     0 0 0 1 0 0 0];   %y3

F = [1 0 0 0;...
     0 1 0 0;...
     0 0 0 1;...
     0 0 0 0;...
     0 0 1 0;...
     0 0 0 0;...
     0 0 0 0;...
     0 0 0 0;...
     0 0 0 0;...
     0 0 0 0];

Z = [0 0 0;...
     0 0 0;...
     0 0 0;...
     0 0 0;...
     0 0 0;...
     0 0 0;...
     0 0 0;...
     1 0 0;...
     0 1 0;...
     0 0 1];

SM = CreateSM(X,F);
SM.name = 'The example from Commault et.al.';

% define measureable variables
svar = SM.x;

% Define if the newly added sensors may also be faulty
%fadd = 1;
fadd = 0;

% perform sensor placement analysis, add sensors, and redo
% the isplability analysis.
senssets = SensPlaceIsolSM(SM,svar,fadd);
SMb = AddSensorsSM(SM,senssets{1},fadd);

[imb,ndfb,dfb] = IsolabilityAnalysisSM(SMb);

